<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" :inline="true" v-show="showSearch" label-width="80px">
      <el-form-item label="企微账号" prop="qwUserId">
		  <el-select v-model="queryParams.qwUserId" placeholder="企微账号" clearable size="small" @change="updateQwuser()">
			<el-option
			  v-for="dict in myQwUserList"
			  :key="dict.dictValue"
			  :label="dict.dictLabel + '('+dict.corpName+')'"
			  :value="dict.dictValue"
			/>
		  </el-select>
      </el-form-item>
      <el-form-item label="客户名称" prop="name">
        <el-input
          v-model="queryParams.name"
          placeholder="请输入客户名称"
          clearable
          size="small"
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>

      <el-form-item label="员工名称" prop="qwUserName">
        <el-input
          v-model="queryParams.qwUserName"
          placeholder="请输入企微员工名称"
          clearable
          size="small"
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>


      <el-form-item>
        <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>
    <el-row :gutter="10" class="mb8">

      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>
    <el-tabs type="card" v-model="queryParams.status" @tab-click="handleClickX">
      <el-tab-pane label="流失" name="3"></el-tab-pane>
      <el-tab-pane label="删除" name="4"></el-tab-pane>
    </el-tabs>
    <el-table v-loading="loading" :data="externalContactList" @selection-change="handleSelectionChange" border>
      <el-table-column type="selection" width="55" align="center" />
      <el-table-column label="企微员工账号" align="center" prop="userId" width="120px"/>
      <el-table-column label="企微员工名称" align="center" prop="qwUserName" width="120px"/>
      <el-table-column label="客户名称" align="center" prop="name" />
      <el-table-column label="头像" align="center" prop="avatar" width="100px">
        <template slot-scope="scope">
          <el-popover
            placement="right"
            title=""
            trigger="hover">
            <img slot="reference" :src="scope.row.avatar" width="60px">
            <img :src="scope.row.avatar" style="max-width: 200px;">
          </el-popover>
        </template>
      </el-table-column>
      <el-table-column label="用户类别" align="center" prop="type">
        <template slot-scope="scope">
          <dict-tag :options="typeOptions" :value="scope.row.type"/>
        </template>
      </el-table-column>
       <el-table-column label="流失时间" align="center" prop="lossTime" v-if="queryParams.status==3"/>
       <el-table-column label="删除时间" align="center" prop="delTime" v-if="queryParams.status==4"/>
      <el-table-column label="状态" align="center" prop="status" width="100px">
        <template slot-scope="scope">
          <dict-tag :options="statusOptions" :value="scope.row.status"/>
        </template>
      </el-table-column>
      <el-table-column label="是否绑定CRM" width="110px" fixed="right">
        <template slot-scope="scope">
          <el-button
            v-if="scope.row.customerId"
            type="success"
            size="mini"
            plain>
            已绑定
          </el-button>
          <el-button
            v-else
            type="danger"
            size="mini"
            plain>
            未绑定
          </el-button>
        </template>
      </el-table-column>
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width" width="120px" fixed="right">
        <template slot-scope="scope">
          <el-button v-if="scope.row.customerId"
                     size="mini"
                     type="text"
                     icon="el-icon-paperclip"
                     @click="handleShow(scope.row)"
          >CRM客户详情</el-button>
        </template>
      </el-table-column>
    </el-table>
    <pagination
      v-show="total>0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />

    <!-- 添加或修改企业微信客户对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="500px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules" label-width="80px">
        <el-form-item label="属于用户账号" prop="userId">
          <el-input v-model="form.userId" placeholder="请输入属于用户账号" />
        </el-form-item>
        <el-form-item label="外部联系人账号" prop="externalUserId">
          <el-input v-model="form.externalUserId" placeholder="请输入外部联系人账号" />
        </el-form-item>
        <el-form-item label="名称" prop="name">
          <el-input v-model="form.name" placeholder="请输入名称" />
        </el-form-item>
        <el-form-item label="头像" prop="avatar">
          <el-input v-model="form.avatar" placeholder="请输入头像" />
        </el-form-item>
        <el-form-item label="用户类别" prop="type">
          <el-select v-model="form.type" placeholder="请选择用户类别">
            <el-option
              v-for="dict in typeOptions"
              :key="dict.dictValue"
              :label="dict.dictLabel"
              :value="parseInt(dict.dictValue)"
            ></el-option>
          </el-select>
        </el-form-item>
        <el-form-item label="性别" prop="gender">
          <el-input v-model="form.gender" placeholder="请输入性别" />
        </el-form-item>
        <el-form-item label="备注" prop="remark">
          <el-input v-model="form.remark" placeholder="请输入备注" />
        </el-form-item>
        <el-form-item label="描述信息" prop="description">
          <el-input v-model="form.description" placeholder="请输入描述信息" />
        </el-form-item>
        <el-form-item label="标签id" prop="tagIds">
          <el-input v-model="form.tagIds" placeholder="请输入标签id" />
        </el-form-item>
        <el-form-item label="备注电话号码" prop="remarkMobiles">
          <el-input v-model="form.remarkMobiles" placeholder="请输入备注电话号码" />
        </el-form-item>
        <el-form-item label="备注企业名称" prop="remarkCorpName">
          <el-input v-model="form.remarkCorpName" placeholder="请输入备注企业名称" />
        </el-form-item>
        <el-form-item label="来源" prop="addWay">
          <el-input v-model="form.addWay" placeholder="请输入来源" />
        </el-form-item>

        <el-form-item label="企业id" prop="corpId">
          <el-input v-model="form.corpId" placeholder="请输入企业id" />
        </el-form-item>
        <el-form-item label="公司id" prop="companyId">
          <el-input v-model="form.companyId" placeholder="请输入公司id" />
        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>



    <el-drawer size="75%" :title="show.title" :visible.sync="show.open">
      <customer-details  ref="customerDetails" />
    </el-drawer>
  </div>
</template>

<script>
import { myList,listExternalContact, getExternalContact, delExternalContact, addExternalContact, updateExternalContact, exportExternalContact } from "@/api/qw/externalContact";
import { listTag, getTag, delTag, addTag, updateTag, exportTag } from "@/api/qw/tag";
import customerDetails from '@/views/qw/externalContact/customerDetails'
import { getMyQwUserList,getMyQwCompanyList } from "@/api/qw/user";
export default {
  name: "ExternalContact",
  components:{customerDetails},
  data() {
    return {
      // 遮罩层
      loading: true,
      // 导出遮罩层
      exportLoading: false,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      myQwUserList:[],
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 企业微信客户表格数据
      externalContactList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      show:{
        title:"客户详情",
        open:false,
      },
      // 用户类别字典
      typeOptions: [],
      // 性别字典
      genderOptions: [],
      // 来源字典
      addWayOptions: [],
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        userId: null,
        qwUserName:null,
        externalUserId: null,
        name: null,
        avatar: null,
        type: null,
        gender: null,
        description: null,
        tagIds: null,
        remarkMobiles: null,
        remarkCorpName: null,
        addWay: null,
        operUserid: null,
        corpId: null,
        companyId: null,
        status:"3",
        transferStatus:null
      },
      // 表单参数
      form: {},
      tagList:[],
      transferStatusOptions:[],
      statusOptions:[],
      // 表单校验
      rules: {
      }
    };
  },
  created() {
    getMyQwUserList().then(response => {
            this.myQwUserList = response.data;
            if(this.myQwUserList!=null){
              this.queryParams.qwUserId=this.myQwUserList[0].dictValue
              this.getList();
            }
    });
    this.getDicts("sys_qw_externalContact_type").then(response => {
      this.typeOptions = response.data;
    });
    this.getDicts("sys_sex").then(response => {
      this.genderOptions = response.data;
    });
    this.getDicts("sys_qw_externalContact_addWay").then(response => {
      this.addWayOptions = response.data;
    });
    listTag().then(response => {
      this.tagList = response.rows;
    });
    this.getDicts("sys_qw_external_contact_status").then(response => {
      this.statusOptions = response.data;
    });
    this.getDicts("sys_qw_transfer_status").then(response => {
      this.transferStatusOptions = response.data;
    });
  },
  methods: {
    updateQwuser(){
      this.getList();
    },
    /** 查询企业微信客户列表 */
    getList() {
      this.loading = true;
      myList(this.queryParams).then(response => {
        this.externalContactList = response.rows;
        this.total = response.total;
        this.loading = false;
      });
    },

    handleClickX(tab, event) {

       this.queryParams.status=tab.name;

      this.handleQuery();
    },


    /** 查看客户详情 */
    handleShow(row){
      this.show.open=true;
      var that=this;
      const tab = "visit";
      setTimeout(() => {
        that.$refs.customerDetails.getDetails(row.customerId);
        that.$refs.customerDetails.handleClick(tab);

      }, 200);
    },

    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        id: null,
        userId: null,
        externalUserId: null,
        name: null,
        avatar: null,
        type: null,
        gender: null,
        remark: null,
        description: null,
        tagIds: null,
        remarkMobiles: null,
        remarkCorpName: null,
        addWay: null,
        operUserid: null,
        corpId: null,
        companyId: null
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
       this.queryParams.qwUserId=this.myQwUserList[0].dictValue
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.id)
      this.single = selection.length!==1
      this.multiple = !selection.length
    },
    /** 新增按钮操作 */
    handleAdd() {
     addExternalContact(this.form).then(response => {
       this.msgSuccess("同步成功");
       this.getList();
     });

    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      const id = row.id || this.ids
      getExternalContact(id).then(response => {
        this.form = response.data;
        this.open = true;
        this.title = "修改企业微信客户";
      });
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate(valid => {
        this.form.corpId=this.queryParams.corpId;
        if (valid) {
          if (this.form.id != null) {
            updateExternalContact(this.form).then(response => {
              this.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            addExternalContact(this.form).then(response => {
              this.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const ids = row.id || this.ids;
      this.$confirm('是否确认删除企业微信客户编号为"' + ids + '"的数据项?', "警告", {
          confirmButtonText: "确定",
          cancelButtonText: "取消",
          type: "warning"
        }).then(function() {
          return delExternalContact(ids);
        }).then(() => {
          this.getList();
          this.msgSuccess("删除成功");
        }).catch(() => {});
    },
    /** 导出按钮操作 */
    handleExport() {
      const queryParams = this.queryParams;
      this.$confirm('是否确认导出所有企业微信客户数据项?', "警告", {
          confirmButtonText: "确定",
          cancelButtonText: "取消",
          type: "warning"
        }).then(() => {
          this.exportLoading = true;
          return exportExternalContact(queryParams);
        }).then(response => {
          this.download(response.msg);
          this.exportLoading = false;
        }).catch(() => {});
    }
  }
};
</script>
